@@ -46,6 +46,8 @@ class Desire2Download(object):
         self.retries = retries
 
         self.br = mechanize.Browser(factory=mechanize.RobustFactory())
+        self.br.addheaders = [('User-agent', 'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.1) \
+                                    Gecko/2008071615 Fedora/3.0.1-1.fc9 Firefox/3.0.1')]
         self.br.set_handle_refresh(mechanize._http.HTTPRefreshProcessor(), max_time=1)
 
         self.br.open(self.ping_url).read()
